/*	File:	volume.cpp 
	Author:	Alex Fedosov
	Date:	October 9, 2000
	Description:	DMZ sound implementation: volume-related functions
*/

#include <dsound.h>
#include "dmz_snd.h"
#include "dmz_snd_internal.h"

int current_volume[MAXSOUNDS];
int current_pan[MAXSOUNDS];

#define DSVOLUME_TO_DB(volume) ((DWORD) (-30 * (100 - volume)))
#define DSPAN_TO_DB(pan) ((DWORD) (pan * 100))

int dmz_snd_get_volume(int sid, int *volume)
{
	if (lpds == NULL) return DMZ_SND_NOT_INIT;
	if (sid < 0 || sid >= MAXSOUNDS) return DMZ_SND_INVALID_SID;
	if (lpsounds[sid] == NULL) return DMZ_SND_UNUSED_SID;

	if (volume != NULL) *volume = current_volume[sid];
	
	return DMZ_SND_SUCCESS;
}

int dmz_snd_set_volume(int sid, int volume)
{
	if (lpds == NULL) return DMZ_SND_NOT_INIT;
	if (sid < 0 || sid >= MAXSOUNDS) return DMZ_SND_INVALID_SID;
	if (lpsounds[sid] == NULL) return DMZ_SND_UNUSED_SID;
	if (volume < 0 || volume > 100) return DMZ_SND_BAD_VOLUME;

	if (lpsounds[sid]->SetVolume(DSVOLUME_TO_DB(volume)) != DS_OK)
		return DMZ_SND_DS_ERROR;

	current_volume[sid] = volume;

	return DMZ_SND_SUCCESS;
}

int dmz_snd_set_pan(int sid, int pan)
{
	if (lpds == NULL) return DMZ_SND_NOT_INIT;
	if (sid < 0 || sid >= MAXSOUNDS) return DMZ_SND_INVALID_SID;
	if (lpsounds[sid] == NULL) return DMZ_SND_UNUSED_SID;
	if (pan < -100 || pan > 100) return DMZ_SND_BAD_PAN;

	if (lpsounds[sid]->SetPan(DSPAN_TO_DB(pan)) != DS_OK)
		return DMZ_SND_DS_ERROR;

	current_pan[sid] = pan;

	return DMZ_SND_SUCCESS;
}

int dmz_snd_get_pan(int sid, int *pan)
{
	if (lpds == NULL) return DMZ_SND_NOT_INIT;
	if (sid < 0 || sid >= MAXSOUNDS) return DMZ_SND_INVALID_SID;
	if (lpsounds[sid] == NULL) return DMZ_SND_UNUSED_SID;

	if (pan != NULL) *pan = current_pan[sid];
	
	return DMZ_SND_SUCCESS;
}
