/*	File:	registry.c
	Author: Alex Fedosov
	Date:	March 20, 2001
	Description:	using Windows registry to save config info
*/

#include <windows.h>
#include "dmzcore.h"

#define DMZ_HIGHEST_TYPE DMZ_CONFIG_STRING
#define MAX_SIZE 255

int last_error = 0;

int dmz_set_config(const char *keyname, const char *option,
				   void *buffer, int size, int type)
{
	LONG lResult;
	HKEY hKey;
	char sClass[] = "";
	DWORD dwType;
	char subkey[MAX_SIZE] = "Software\\";
	int rv = DMZ_CORE_SUCCESS;

	if (keyname == NULL || option == NULL || buffer == NULL ||
		size < 0 || size > MAX_SIZE || type > DMZ_HIGHEST_TYPE)
		return DMZ_CORE_INVALID_PARAM;

	switch (type)
	{
	case DMZ_CONFIG_INT:
		dwType = REG_DWORD;
		break;
	case DMZ_CONFIG_STRING:
		dwType = REG_SZ;
		break;
	default:
		return DMZ_CORE_INVALID_PARAM;
		break;
	}

	if (strlen(subkey) + strlen(keyname) > MAX_SIZE)
		return DMZ_CORE_INVALID_PARAM;

	strcat(subkey, keyname);

	lResult = RegOpenKeyEx(HKEY_CURRENT_USER, subkey,
			0, KEY_ALL_ACCESS, &hKey);

	if (lResult != ERROR_SUCCESS)
	{
		lResult = RegCreateKeyEx(HKEY_CURRENT_USER, subkey, 0,
			/*sClass,*/NULL, REG_OPTION_NON_VOLATILE, KEY_ALL_ACCESS,
			NULL, &hKey, NULL);

		if (lResult != ERROR_SUCCESS)
		{
			last_error = lResult;
			return DMZ_CORE_CONFIG_ERR;
		}
	}

	lResult = RegSetValueEx(hKey, option, 0, dwType, buffer, size);
	if (lResult != ERROR_SUCCESS)
	{
		last_error = lResult;
		rv = DMZ_CORE_CONFIG_ERR;
	}

	RegCloseKey(hKey);

	return rv;
}

int dmz_get_config(const char *keyname, const char *option,
				   void *buffer, int size, int type)
{
	LONG lResult;
	HKEY hKey;
	DWORD dwType;
	char subkey[MAX_SIZE] = "Software\\";
	int rv = DMZ_CORE_SUCCESS;

	if (keyname == NULL || option == NULL || buffer == NULL ||
		size < 0 || size > MAX_SIZE || type > DMZ_HIGHEST_TYPE)
		return DMZ_CORE_INVALID_PARAM;

	if (strlen(subkey) + strlen(keyname) > MAX_SIZE)
		return DMZ_CORE_INVALID_PARAM;

	strcat(subkey, keyname);

	lResult = RegOpenKeyEx(HKEY_CURRENT_USER, subkey,
		0, KEY_ALL_ACCESS, &hKey);

	if (lResult != ERROR_SUCCESS)
	{
		last_error = lResult;
		return DMZ_CORE_CONFIG_ERR;
	}

	lResult = RegQueryValueEx(hKey, option, NULL, &dwType,
		buffer, &size);

	if (lResult != ERROR_SUCCESS)
	{
		last_error = lResult;
		rv = DMZ_CORE_CONFIG_ERR;
	}

	RegCloseKey(hKey);

	return rv;
}

int dmz_core_get_last_error(void)
{
	return last_error;
}
		
