/*	File:	dmz_net.h 
	Author:	Nancy Montanez
	Date:	October 9, 2000
	Description:	DMZ network API
	Modified: November 22, 2000, now works for C and C++ files -- Completed November 24, 2000
*/

#ifndef __DMZ_NET_H__
#define __DMZ_NET_H__

/* want to make this work for both C and C++ */
#ifdef WIN32	/* Windows */
	#ifdef __cplusplus

		#ifdef DMZ_NET_EXPORTS
		#define DMZ_NET_API extern "C" __declspec(dllexport)
		#else
		#define DMZ_NET_API extern "C" __declspec(dllimport)
		#endif
	#else
		#ifdef DMZ_NET_EXPORTS
		#define DMZ_NET_API __declspec(dllexport)
		#else
		#define DMZ_NET_API __declspec(dllimport)
		#endif
	#endif
#else		/* Unix / Linux */
	#define DMZ_NET_API
	#include <sys/time.h>
#endif

typedef enum 
{
	BLOCKING,
	NONBLOCKING
} DMZ_SOCKET_MODE;

/* Function Prototypes for the the network library	*/
DMZ_NET_API int dmz_send_msg(void *msg, int size, int connect_id);
DMZ_NET_API int dmz_recv_msg(void *msg, int size, int connect_id);
DMZ_NET_API int dmz_net_init(void);
DMZ_NET_API int dmz_connect(char *peer, int port);
DMZ_NET_API int dmz_listen(int port, int max);
DMZ_NET_API void dmz_disconnect(int id);
DMZ_NET_API void dmz_net_kill(void);
DMZ_NET_API int dmz_accept(int listen_index);
DMZ_NET_API int dmz_avail_socket(void);
DMZ_NET_API	int dmz_net_multiplex(int *read_set, int *write_set, int *accept_set,
							   int *read_ids, int *write_ids, int *accept_ids,
							   struct timeval *timeout);
DMZ_NET_API int dmz_net_chmode(int connid, DMZ_SOCKET_MODE mode);
DMZ_NET_API char* dmz_net_getpeer(int connid);
DMZ_NET_API int dmz_net_get_local_IP(char *buffer);

/* Error codes	*/

typedef enum{
DMZ_NET_SUCCESS			=	42,
DMZ_NET_INVALID_PARAM	=	-1,
DMZ_NET_TOO_MANY_SOCS	=	-2,
DMZ_NET_SOCKET_ERROR	=	-3, 
DMZ_NET_NO_CONNECT		=	-4,
DMZ_NET_NONBLOCKING_ERR	=	-5,
DMZ_NET_NOT_INIT		=	-6,
DMZ_NET_BINDING_ERR		=	-8,
DMZ_NET_LISTEN_ERR		=	-9,
DMZ_NET_RECV_ERROR		=	-10,
DMZ_NET_SEND_ERROR		=	-11,
DMZ_NET_INIT_FAILED		=	-12,
DMZ_NET_TRY_AGAIN		=	-13,
DMZ_NET_NOTHING_TO_RECV	=	-14,
DMZ_NET_INIT_ALREADY_DONE	=	-15,
DMZ_NET_ACCEPT_ERR		=	-16
} DMZ_NET_ERC;


#endif



